@@ -7,8 +7,9 @@ display.lm <- function(object, digits=2){
     k <- summ$df[1]
     print (call)
     pfround (coef, digits)
-    cat (paste ("  n = ", n, ", k = ", k,
-    "\n  residual sd = ", fround (summ$sigma, digits),
+    cat("---\n")
+    cat (paste ("n = ", n, ", k = ", k,
+    "\nresidual sd = ", fround (summ$sigma, digits),
     ", R-Squared = ", fround (summ$r.squared, 2), "\n", sep=""))
 }
 
@@ -23,7 +24,8 @@ display.glm <- function (object, digits = 2){
     k <- summ$df[1]
     print(call)
     pfround(coef, digits)
-    cat(paste("  n = ", n, ", k = ", k, "\n  residual deviance = ", 
+    cat("---\n")
+    cat(paste("n = ", n, ", k = ", k, "\nresidual deviance = ", 
         fround(summ$deviance, 1), ", null deviance = ", fround(summ$null.deviance, 
             1), " (difference = ", fround(summ$null.deviance - 
             summ$deviance, 1), ")", "\n", sep = ""))
@@ -34,7 +36,7 @@ display.glm <- function (object, digits = 2){
         cat(paste("overdispersion parameter = ", fround(dispersion, 
             1), "\n", sep = ""))
         if (family(object)$family == "gaussian") {
-            cat(paste("  residual sd is sqrt(overdispersion) = ", 
+            cat(paste("residual sd is sqrt(overdispersion) = ", 
                 fround(sqrt(dispersion), digits), "\n", sep = ""))
         }
     }
@@ -45,27 +47,28 @@ display.mer <- function(object, digits=2){
     call <- object@call
     print (call)
     #object <- summary(object)
-    fcoef <- .Call("mer_fixef", object, PACKAGE = "lme4")
-    useScale <- object@devComp[8]
+    fcoef <- fixef(object)
+    useScale <- attr( VarCorr(object), "sc") 
     corF <- vcov(object)@factors$correlation
     coefs <- cbind(fcoef, corF@sd)
     if (length (fcoef) > 0){
       dimnames(coefs) <- list(names(fcoef), c("coef.est", "coef.se"))
       pfround (coefs, digits)
     }
-    cat("Error terms:\n")
+    cat("\nError terms:\n")
     vc <- as.matrix.VarCorr (VarCorr (object), useScale=useScale, digits)
     print (vc[,c(1:2,4:ncol(vc))], quote=FALSE)
     ngrps <- lapply(object@flist, function(x) length(levels(x)))
     REML <- object@status["REML"]
     llik <- logLik(object, REML)
     AIC <- AIC(llik)
-    dev <- object@deviance[1]     # Dbar
-    devc <- object@devComp
+    dev <- object@deviance["ML"]     # Dbar
+    n <- object@devComp["n"]
     Dhat <- -2*(llik) # Dhat
     pD <- dev - Dhat              # pD
     DIC <- dev + pD               # DIC=Dbar+pD=Dhat+2pD
-    cat(sprintf("number of obs: %d, groups: ", devc[1]))
+    cat("---\n")
+    cat(sprintf("number of obs: %d, groups: ", n))
     cat(paste(paste(names(ngrps), ngrps, sep = ", "), collapse = "; "))
     cat(sprintf("\nAIC = %g, DIC = ", fround(AIC, 1)))
     cat(fround(DIC, 1))
@@ -89,18 +92,20 @@ display.mer2 <- function(object, digits=2){
       dimnames(coefs) <- list(names(fcoef), c("coef.est", "coef.se"))
       pfround (coefs, digits)
     }
-    cat("Error terms:\n")
+    cat("\nError terms:\n")
     vc <- as.matrix.VarCorr (VarCorr (object), useScale=useScale, digits)
     print (vc[,c(1:2,4:ncol(vc))], quote=FALSE)
     ngrps <- lapply(object@flist, function(x) length(levels(x)))
-    llik <- logLik(object)
+    REML <- object@dims["isREML"]
+    llik <- logLik(object, REML)
     AIC <- AIC(llik)
-    dev <- object@deviance[1]     # Dbar
-    devc <- object@dims
+    dev <- object@deviance["ML"]     # Dbar
+    n <- object@dims["n"]
     Dhat <- -2*(llik) # Dhat
     pD <- dev - Dhat              # pD
     DIC <- dev + pD               # DIC=Dbar+pD=Dhat+2pD
-    cat(sprintf("number of obs: %d, groups: ", devc[2]))
+    cat("---\n")
+    cat(sprintf("number of obs: %d, groups: ", n))
     cat(paste(paste(names(ngrps), ngrps, sep = ", "), collapse = "; "))
     cat(sprintf("\nAIC = %g, DIC = ", fround(AIC,1)))
     cat(fround(DIC, 1))
@@ -124,8 +129,9 @@ display.polr <- function(object, digits=2){
     k.intercepts <- length (summ$zeta)
     print(call)
     pfround(coef, digits)
-    cat(paste("  n = ", n, ", k = ", k, " (including ", k.intercepts,
-        " intercepts)\n  residual deviance = ",
+    cat("---\n")
+    cat(paste("n = ", n, ", k = ", k, " (including ", k.intercepts,
+        " intercepts)\nresidual deviance = ",
         fround(summ$deviance, 1), 
         ", null deviance is not computed by polr",
         "\n", sep = ""))
